#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IUserExternalAccount_VERSION = "3.1.42688"

class IUserExternalAccount(BaseEndpoint):
    def __init__(self, apiKey, url ,domain ,uid ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/users/{domain}/{uid}/accounts'
        self.domain_ = domain
        self.base = self.base.replace('{domain}',domain)
        self.uid_ = uid
        self.base = self.base.replace('{uid}',uid)

    def getAll (self):
        postUri = "";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUserExternalAccount_VERSION}, data = __encoded__);
        from netbluemind.user.api.UserAccountInfo import UserAccountInfo
        from netbluemind.user.api.UserAccountInfo import __UserAccountInfoSerDer__
        return self.handleResult__(serder.ListSerDer(__UserAccountInfoSerDer__()), response)
    def deleteAll (self):
        postUri = "";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUserExternalAccount_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def update (self, system , account ):
        postUri = "/{system}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{system}",system);
        from netbluemind.user.api.UserAccount import UserAccount
        from netbluemind.user.api.UserAccount import __UserAccountSerDer__
        __data__ = __UserAccountSerDer__().encode(account)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUserExternalAccount_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def delete (self, system ):
        postUri = "/{system}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{system}",system);
        queryParams = {   };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUserExternalAccount_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def get (self, system ):
        postUri = "/{system}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{system}",system);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUserExternalAccount_VERSION}, data = __encoded__);
        from netbluemind.user.api.UserAccount import UserAccount
        from netbluemind.user.api.UserAccount import __UserAccountSerDer__
        return self.handleResult__(__UserAccountSerDer__(), response)
    def create (self, system , account ):
        postUri = "/{system}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{system}",system);
        from netbluemind.user.api.UserAccount import UserAccount
        from netbluemind.user.api.UserAccount import __UserAccountSerDer__
        __data__ = __UserAccountSerDer__().encode(account)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUserExternalAccount_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class CalendarViewChanges :
    def __init__( self):
        self.add = None
        self.modify = None
        self.delete = None
        pass

class __CalendarViewChangesSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = CalendarViewChanges()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.calendar.api.CalendarViewChangesItemAdd import CalendarViewChangesItemAdd
        from netbluemind.calendar.api.CalendarViewChangesItemAdd import __CalendarViewChangesItemAddSerDer__
        addValue = value['add']
        instance.add = serder.ListSerDer(__CalendarViewChangesItemAddSerDer__()).parse(addValue)
        from netbluemind.calendar.api.CalendarViewChangesItemModify import CalendarViewChangesItemModify
        from netbluemind.calendar.api.CalendarViewChangesItemModify import __CalendarViewChangesItemModifySerDer__
        modifyValue = value['modify']
        instance.modify = serder.ListSerDer(__CalendarViewChangesItemModifySerDer__()).parse(modifyValue)
        from netbluemind.calendar.api.CalendarViewChangesItemDelete import CalendarViewChangesItemDelete
        from netbluemind.calendar.api.CalendarViewChangesItemDelete import __CalendarViewChangesItemDeleteSerDer__
        deleteValue = value['delete']
        instance.delete = serder.ListSerDer(__CalendarViewChangesItemDeleteSerDer__()).parse(deleteValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.calendar.api.CalendarViewChangesItemAdd import CalendarViewChangesItemAdd
        from netbluemind.calendar.api.CalendarViewChangesItemAdd import __CalendarViewChangesItemAddSerDer__
        addValue = value.add
        instance["add"] = serder.ListSerDer(__CalendarViewChangesItemAddSerDer__()).encode(addValue)
        from netbluemind.calendar.api.CalendarViewChangesItemModify import CalendarViewChangesItemModify
        from netbluemind.calendar.api.CalendarViewChangesItemModify import __CalendarViewChangesItemModifySerDer__
        modifyValue = value.modify
        instance["modify"] = serder.ListSerDer(__CalendarViewChangesItemModifySerDer__()).encode(modifyValue)
        from netbluemind.calendar.api.CalendarViewChangesItemDelete import CalendarViewChangesItemDelete
        from netbluemind.calendar.api.CalendarViewChangesItemDelete import __CalendarViewChangesItemDeleteSerDer__
        deleteValue = value.delete
        instance["delete"] = serder.ListSerDer(__CalendarViewChangesItemDeleteSerDer__()).encode(deleteValue)
        return instance




from netbluemind.python import serder
import time
import sys

class BMClient:
    def __init__(self, baseUrl, apiKey = None):
        self.baseUrl = baseUrl
        self.apiKey = apiKey

    def instance(self, klass, *args):
        ccArgs = []
        ccArgs.append(self.apiKey)
        ccArgs.append(self.baseUrl)
        for a in args:
            ccArgs.append(a)

        return klass(*ccArgs)

    def login(self, login, password):
        from netbluemind.authentication.api.IAuthentication import IAuthentication
        auth = self.instance(IAuthentication)
        res = auth.login(login, password, "python")
        if( res.status.name == 'Bad'):
            raise ServerFault(None, None, "Bad login/pass")
        else:
            self.apiKey = res.authKey

    def domains(self):
        from netbluemind.domain.api.IDomains import IDomains
        return self.instance(IDomains)

    def directory(self, domain):
        from netbluemind.directory.api.IDirectory import IDirectory
        return self.instance(IDirectory, domain)

    def users(self, domain):
        from netbluemind.user.api.IUser import IUser
        return self.instance(IUser,domain)

    def groups(self, domain):
        from netbluemind.group.api.IGroup import IGroup
        return self.instance(IGroup,domain)

    def addressbook(self, uid):
        from netbluemind.addressbook.api.IAddressBook import IAddressBook
        return self.instance(IAddressBook,uid)

    def calendar(self, uid):
        from netbluemind.calendar.api.ICalendar import ICalendar
        return self.instance(ICalendar,uid)

    def mailboxes(self, domain):
        from netbluemind.mailbox.api.IMailboxes import IMailboxes
        return self.instance(IMailboxes, domain)

    def mailboxesMgmt(self, domain):
        from netbluemind.mailbox.api.IMailboxMgmt import IMailboxMgmt
        return self.instance(IMailboxMgmt, domain)

    def containerMgmt(self, containerUid):
        from netbluemind.core.container.api.IContainerManagement import IContainerManagement
        return self.instance(IContainerManagement, containerUid)

    def installation(self):
        from netbluemind.system.api.IInstallation import IInstallation
        return self.instance(IInstaltion)

    def servers(self, containerUid):
        from netbluemind.server.api.IServer import IServer
        return self.instance(IServer, containerUid)

    def domains(self):
        from netbluemind.domain.api.IDomains import IDomains
        return self.instance(IDomains)

    def domainSettings(self, domainUid):
        from netbluemind.domain.api.IDomainSettings import IDomainSettings
        return self.instance(IDomainSettings, domainUid)

    def userDevices(self, userUid):
        from netbluemind.device.api.IDevice import IDevice
        return self.instance(IDevice, userUid)

    def task(self, taskRef):
        from netbluemind.core.task.api.ITask import ITask
        return self.instance(ITask, taskRef.id)

    def jobs(self):
        from netbluemind.scheduledjob.api.IJob import IJob
        return self.instance(IJob)

    def waitTask(self, taskRef):
        from netbluemind.core.task.api.ITask import ITask
        from netbluemind.core.task.api.TaskStatusState import TaskStatusState
        task = self.instance(ITask, taskRef.id)
        status = task.status()
        while( status.state != TaskStatusState.InError and status.state != TaskStatusState.Success):
            time.sleep(0.1)
            status = task.status()
        return status

class BaseEndpoint:
    def handleResult__(self, sd, response):
        if ( "X-BM-WarnMessage" in response.headers):
            sys.stderr.write(response.headers["X-BM-WarnMessage"])

        if ( response.status_code == 204 ):
            return None
        elif( response.status_code <= 400 ):
            if( sd != None and serder.VOID != sd ):
                return sd.parse(response.json())
            else :
                return
        else:
            try:
                sf = response.json()
                raise ServerFault(sf.get("errorCode", 0),
                   sf.get("errorType", None),
                    sf.get("message", "unknown"))
            except ValueError:
                raise ServerFault(0, None, "unknown")

class ServerFault(Exception):
    def __init__(self, errorCode, errorType, message):
        super(ServerFault, self).__init__(errorCode, errorType, message)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ContainerSyncResult :
    def __init__( self):
        self.status = None
        self.added = None
        self.updated = None
        self.removed = None
        self.unhandled = None
        pass

class __ContainerSyncResultSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = ContainerSyncResult()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.core.container.model.ContainerSyncStatus import ContainerSyncStatus
        from netbluemind.core.container.model.ContainerSyncStatus import __ContainerSyncStatusSerDer__
        statusValue = value['status']
        instance.status = __ContainerSyncStatusSerDer__().parse(statusValue)
        addedValue = value['added']
        instance.added = serder.INT.parse(addedValue)
        updatedValue = value['updated']
        instance.updated = serder.INT.parse(updatedValue)
        removedValue = value['removed']
        instance.removed = serder.INT.parse(removedValue)
        unhandledValue = value['unhandled']
        instance.unhandled = serder.INT.parse(unhandledValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.core.container.model.ContainerSyncStatus import ContainerSyncStatus
        from netbluemind.core.container.model.ContainerSyncStatus import __ContainerSyncStatusSerDer__
        statusValue = value.status
        instance["status"] = __ContainerSyncStatusSerDer__().encode(statusValue)
        addedValue = value.added
        instance["added"] = serder.INT.encode(addedValue)
        updatedValue = value.updated
        instance["updated"] = serder.INT.encode(updatedValue)
        removedValue = value.removed
        instance["removed"] = serder.INT.encode(removedValue)
        unhandledValue = value.unhandled
        instance["unhandled"] = serder.INT.encode(unhandledValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder
from enum import Enum

class FolderType(Enum):
    user_created_folder = 'user_created_folder';
    default_inbox = 'default_inbox';
    default_drafts = 'default_drafts';
    default_trash = 'default_trash';
    default_sent = 'default_sent';
    default_outbox = 'default_outbox';
    default_todolist = 'default_todolist';
    default_calendar = 'default_calendar';
    default_addressbook = 'default_addressbook';
    default_notes = 'default_notes';
    default_journal = 'default_journal';
    user_created_mail = 'user_created_mail';
    user_created_calendar = 'user_created_calendar';
    user_created_addressbook = 'user_created_addressbook';
    user_created_todolist = 'user_created_todolist';
    user_created_journal = 'user_created_journal';
    user_created_notes = 'user_created_notes';
    unknown = 'unknown';
    recipient_information_cache = 'recipient_information_cache';
    system = 'system';
    root = 'root';
    other_mailboxes = 'other_mailboxes';
    other_calendars = 'other_calendars';
    other_addressbooks = 'other_addressbooks';
    other_todolists = 'other_todolists';
    default_mailbox = 'default_mailbox';
    other_mailbox = 'other_mailbox';

class __FolderTypeSerDer__:
    def __init__( self):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = FolderType[value]
        return instance


    def encode(self, value):
        if(value == None):
            return None
        instance = value.value
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VEventAttendeeQuery :
    def __init__( self):
        self.dir = None
        self.calendarOwnerAsDir = None
        self.partStatus = None
        pass

class __VEventAttendeeQuerySerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = VEventAttendeeQuery()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        dirValue = value['dir']
        instance.dir = serder.STRING.parse(dirValue)
        calendarOwnerAsDirValue = value['calendarOwnerAsDir']
        instance.calendarOwnerAsDir = serder.BOOLEAN.parse(calendarOwnerAsDirValue)
        from netbluemind.icalendar.api.ICalendarElementParticipationStatus import ICalendarElementParticipationStatus
        from netbluemind.icalendar.api.ICalendarElementParticipationStatus import __ICalendarElementParticipationStatusSerDer__
        partStatusValue = value['partStatus']
        instance.partStatus = __ICalendarElementParticipationStatusSerDer__().parse(partStatusValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        dirValue = value.dir
        instance["dir"] = serder.STRING.encode(dirValue)
        calendarOwnerAsDirValue = value.calendarOwnerAsDir
        instance["calendarOwnerAsDir"] = serder.BOOLEAN.encode(calendarOwnerAsDirValue)
        from netbluemind.icalendar.api.ICalendarElementParticipationStatus import ICalendarElementParticipationStatus
        from netbluemind.icalendar.api.ICalendarElementParticipationStatus import __ICalendarElementParticipationStatusSerDer__
        partStatusValue = value.partStatus
        instance["partStatus"] = __ICalendarElementParticipationStatusSerDer__().encode(partStatusValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Job :
    def __init__( self):
        self.domainStatus = None
        self.domainPlanification = None
        self.id = None
        self.description = None
        self.kind = None
        self.sendReport = None
        self.recipients = None
        pass

class __JobSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = Job()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.scheduledjob.api.JobDomainStatus import JobDomainStatus
        from netbluemind.scheduledjob.api.JobDomainStatus import __JobDomainStatusSerDer__
        domainStatusValue = value['domainStatus']
        instance.domainStatus = serder.ListSerDer(__JobDomainStatusSerDer__()).parse(domainStatusValue)
        from netbluemind.scheduledjob.api.JobPlanification import JobPlanification
        from netbluemind.scheduledjob.api.JobPlanification import __JobPlanificationSerDer__
        domainPlanificationValue = value['domainPlanification']
        instance.domainPlanification = serder.ListSerDer(__JobPlanificationSerDer__()).parse(domainPlanificationValue)
        idValue = value['id']
        instance.id = serder.STRING.parse(idValue)
        descriptionValue = value['description']
        instance.description = serder.STRING.parse(descriptionValue)
        from netbluemind.scheduledjob.api.JobKind import JobKind
        from netbluemind.scheduledjob.api.JobKind import __JobKindSerDer__
        kindValue = value['kind']
        instance.kind = __JobKindSerDer__().parse(kindValue)
        sendReportValue = value['sendReport']
        instance.sendReport = serder.BOOLEAN.parse(sendReportValue)
        recipientsValue = value['recipients']
        instance.recipients = serder.STRING.parse(recipientsValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.scheduledjob.api.JobDomainStatus import JobDomainStatus
        from netbluemind.scheduledjob.api.JobDomainStatus import __JobDomainStatusSerDer__
        domainStatusValue = value.domainStatus
        instance["domainStatus"] = serder.ListSerDer(__JobDomainStatusSerDer__()).encode(domainStatusValue)
        from netbluemind.scheduledjob.api.JobPlanification import JobPlanification
        from netbluemind.scheduledjob.api.JobPlanification import __JobPlanificationSerDer__
        domainPlanificationValue = value.domainPlanification
        instance["domainPlanification"] = serder.ListSerDer(__JobPlanificationSerDer__()).encode(domainPlanificationValue)
        idValue = value.id
        instance["id"] = serder.STRING.encode(idValue)
        descriptionValue = value.description
        instance["description"] = serder.STRING.encode(descriptionValue)
        from netbluemind.scheduledjob.api.JobKind import JobKind
        from netbluemind.scheduledjob.api.JobKind import __JobKindSerDer__
        kindValue = value.kind
        instance["kind"] = __JobKindSerDer__().encode(kindValue)
        sendReportValue = value.sendReport
        instance["sendReport"] = serder.BOOLEAN.encode(sendReportValue)
        recipientsValue = value.recipients
        instance["recipients"] = serder.STRING.encode(recipientsValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IAddressBook_VERSION = "3.1.42688"

class IAddressBook(BaseEndpoint):
    def __init__(self, apiKey, url ,containerUid ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/addressbooks/{containerUid}'
        self.containerUid_ = containerUid
        self.base = self.base.replace('{containerUid}',containerUid)

    def getPhoto (self, uid ):
        postUri = "/{uid}/photo";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        return self.handleResult__(serder.ByteArraySerDer, response)
    def allUids (self):
        postUri = "";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
    def update (self, uid , card ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        from netbluemind.addressbook.api.VCard import VCard
        from netbluemind.addressbook.api.VCard import __VCardSerDer__
        __data__ = __VCardSerDer__().encode(card)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def updates (self, changes ):
        postUri = "/_mupdates";
        __data__ = None
        __encoded__ = None
        from netbluemind.addressbook.api.VCardChanges import VCardChanges
        from netbluemind.addressbook.api.VCardChanges import __VCardChangesSerDer__
        __data__ = __VCardChangesSerDer__().encode(changes)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.ContainerUpdatesResult import ContainerUpdatesResult
        from netbluemind.core.container.model.ContainerUpdatesResult import __ContainerUpdatesResultSerDer__
        return self.handleResult__(__ContainerUpdatesResultSerDer__(), response)
    def delete (self, uid ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def deletePhoto (self, uid ):
        postUri = "/{uid}/photo";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def changeset (self, since ):
        postUri = "/_changeset";
        __data__ = None
        __encoded__ = None
        queryParams = {  'since': since   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
    def changesetById (self, since ):
        postUri = "/_changesetById";
        __data__ = None
        __encoded__ = None
        queryParams = {  'since': since   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
        return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
    def search (self, query ):
        postUri = "/_search";
        __data__ = None
        __encoded__ = None
        from netbluemind.addressbook.api.VCardQuery import VCardQuery
        from netbluemind.addressbook.api.VCardQuery import __VCardQuerySerDer__
        __data__ = __VCardQuerySerDer__().encode(query)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        from netbluemind.addressbook.api.VCardInfo import VCardInfo
        from netbluemind.addressbook.api.VCardInfo import __VCardInfoSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        from netbluemind.core.api.ListResult import ListResult
        from netbluemind.core.api.ListResult import __ListResultSerDer__
        return self.handleResult__(__ListResultSerDer__(__ItemValueSerDer__(__VCardInfoSerDer__())), response)
    def create (self, uid , card ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        from netbluemind.addressbook.api.VCard import VCard
        from netbluemind.addressbook.api.VCard import __VCardSerDer__
        __data__ = __VCardSerDer__().encode(card)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def copy (self, uids , destContainerUid ):
        postUri = "/_copy/{destContainerUid}";
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
        __encoded__ = json.dumps(__data__)
        postUri = postUri.replace("{destContainerUid}",destContainerUid);
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getVersion (self):
        postUri = "/_version";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        return self.handleResult__(serder.LONG, response)
    def move (self, uids , destContainerUid ):
        postUri = "/_move/{destContainerUid}";
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
        __encoded__ = json.dumps(__data__)
        postUri = postUri.replace("{destContainerUid}",destContainerUid);
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def multipleGet (self, uids ):
        postUri = "/_mget";
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        from netbluemind.addressbook.api.VCard import VCard
        from netbluemind.addressbook.api.VCard import __VCardSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VCardSerDer__())), response)
    def getInfo (self, uid ):
        postUri = "/{uid}/info";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        from netbluemind.addressbook.api.VCardInfo import VCardInfo
        from netbluemind.addressbook.api.VCardInfo import __VCardInfoSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__VCardInfoSerDer__()), response)
    def sync (self, since , changes ):
        postUri = "/_sync";
        __data__ = None
        __encoded__ = None
        from netbluemind.addressbook.api.VCardChanges import VCardChanges
        from netbluemind.addressbook.api.VCardChanges import __VCardChangesSerDer__
        __data__ = __VCardChangesSerDer__().encode(changes)
        __encoded__ = json.dumps(__data__)
        queryParams = {  'since': since    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
    def itemChangelog (self, uid , arg1 ):
        postUri = "/{uid}/_itemchangelog";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        __data__ = serder.LONG.encode(arg1)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
        return self.handleResult__(__ItemChangelogSerDer__(), response)
    def getIcon (self, uid ):
        postUri = "/{uid}/icon";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        return self.handleResult__(serder.ByteArraySerDer, response)
    def getComplete (self, uid ):
        postUri = "/{uid}/complete";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        from netbluemind.addressbook.api.VCard import VCard
        from netbluemind.addressbook.api.VCard import __VCardSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__VCardSerDer__()), response)
    def containerChangelog (self, arg0 ):
        postUri = "/_changelog";
        __data__ = None
        __encoded__ = None
        __data__ = serder.LONG.encode(arg0)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
        return self.handleResult__(__ContainerChangelogSerDer__(), response)
    def setPhoto (self, uid , photo ):
        postUri = "/{uid}/photo";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        __data__ = serder.ByteArraySerDer.encode(photo)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def reset (self):
        postUri = "/_reset";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def createById (self, id , card ):
        postUri = "/_byId";
        __data__ = None
        __encoded__ = None
        from netbluemind.addressbook.api.VCard import VCard
        from netbluemind.addressbook.api.VCard import __VCardSerDer__
        __data__ = __VCardSerDer__().encode(card)
        __encoded__ = json.dumps(__data__)
        queryParams = {  'id': id    };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VEventChangesItemAdd :
    def __init__( self):
        self.uid = None
        self.value = None
        self.sendNotification = None
        pass

class __VEventChangesItemAddSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = VEventChangesItemAdd()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        uidValue = value['uid']
        instance.uid = serder.STRING.parse(uidValue)
        from netbluemind.calendar.api.VEventSeries import VEventSeries
        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
        valueValue = value['value']
        instance.value = __VEventSeriesSerDer__().parse(valueValue)
        sendNotificationValue = value['sendNotification']
        instance.sendNotification = serder.BOOLEAN.parse(sendNotificationValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        uidValue = value.uid
        instance["uid"] = serder.STRING.encode(uidValue)
        from netbluemind.calendar.api.VEventSeries import VEventSeries
        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
        valueValue = value.value
        instance["value"] = __VEventSeriesSerDer__().encode(valueValue)
        sendNotificationValue = value.sendNotification
        instance["sendNotification"] = serder.BOOLEAN.encode(sendNotificationValue)
        return instance

